@@ -1,8 +1,6 @@
 from redis import StrictRedis
 import sys
-
-sys.path.append('../')
-from service.SettingService import Redis
+from SettingService import Redis
 
 class CacheService:
     def __init__(self,settings):
